@@ -143,7 +143,16 @@ class CompsPlatformExperimentOperations(IPlatformExperimentOperations):
             exclusive=self.platform.exclusive
         )
 
-        if kwargs.get("scheduling", False):
+        if isinstance(experiment.simulations.items, TemplatedSimulations):
+            scheduling = getattr(experiment.simulations.items.base_simulation, 'scheduling', False)
+        elif isinstance(experiment.simulations.items, List):
+            scheduling = getattr(experiment.simulations.items[0], 'scheduling', False)
+        else:
+            scheduling = False
+
+        # kwargs.get("scheduling", False) case is for adding work_order file during sweeping call back which is too late
+        # to detect the scheduling flag from the simulation
+        if scheduling or kwargs.get("scheduling", False):
             import copy
             # save a copy of default config
             setattr(self.platform, 'comps_config', copy.deepcopy(comps_config))
@@ -262,7 +271,7 @@ class CompsPlatformExperimentOperations(IPlatformExperimentOperations):
             user_logger.log(SUCCESS, f"\nThe created experiment can be viewed at {self.platform.endpoint}/#explore/"
                                      f"Simulations?filters=ExperimentId={experiment.uid}\nSimulations are still being created\n"
                             )
-        experiment.post_creation(self.platform)
+        super().post_create(experiment, **kwargs)
 
     def post_run_item(self, experiment: Experiment, **kwargs):
         """
@@ -401,8 +410,7 @@ class CompsPlatformExperimentOperations(IPlatformExperimentOperations):
                 suite = kwargs.get('suite') or self.platform.get_item(experiment.suite_id, item_type=ItemType.SUITE)
 
         # Create an experiment
-        experiment_type = experiment.tags.get("type") if experiment.tags is not None else ""
-        obj = experiment_factory.create(experiment_type, tags=experiment.tags, name=experiment.name,
+        obj = experiment_factory.create("idmtools.entities.experiment.Experiment", tags=experiment.tags, name=experiment.name,
                                         fallback=Experiment)
         obj.platform = self.platform
         obj._platform_object = experiment
@@ -410,7 +418,7 @@ class CompsPlatformExperimentOperations(IPlatformExperimentOperations):
         obj.parent = suite
         # Set the correct attributes
         obj.uid = experiment.id
-        obj.comps_experiment = experiment
+        obj.task_type = experiment.tags.get("task_type") if experiment.tags is not None else ""
         # load assets first so children can access during their load
         obj.assets = self.get_assets_from_comps_experiment(experiment)
         if obj.assets is None:
@@ -521,3 +529,41 @@ class CompsPlatformExperimentOperations(IPlatformExperimentOperations):
         comps_experiment = self.platform.get_item(experiment_id, ItemType.EXPERIMENT, raw=True)
         if comps_experiment and experiment_is_running(comps_experiment):
             comps_experiment.cancel()
+
+    def get_assets(self, experiment: Experiment, files: List[str], include_experiment_assets: bool = True, **kwargs) -> Dict[str, bytearray]:
+        """
+        Fetch the files associated with an experiment and its simulations.
+
+        Args:
+            experiment (Experiment): The experiment object.
+            files (List[str]): A list of filenames to retrieve.
+            include_experiment_assets (bool): Whether to include experiment-level assets. Defaults to True.
+            **kwargs: Additional platform-specific options.
+
+        Returns:
+            Dict[str, Dict[str, Dict[str, Union[str, bytearray]]]]: A nested dictionary in the format::
+
+                {
+                    "experiment_id": {
+                        "simulation_id": {
+                            "filename1": file_content,
+                            "filename2": file_content,
+                            ...
+                        },
+                        ...
+                    }
+                }
+
+            File content may be either a decoded string or a bytearray.
+        """
+        ret = dict()
+        if isinstance(experiment, COMPSExperiment):
+            comps_exp = experiment
+        else:
+            comps_exp = experiment.get_platform_object()
+        simulations = self.platform.flatten_item(comps_exp, raw=True)
+        for sim in simulations:
+            ret[sim.id] = self.platform._simulations.get_assets(sim, files,
+                                                                include_experiment_assets=include_experiment_assets,
+                                                                **kwargs)
+        return ret
